#[non_exhaustive]pub enum SquareColor {
Light,
Dark,
}Expand description
Colour of a square — the default binary partition used by chess
(and the default type parameter C for Constraint /
crate::Problem).
For N-way colour partitions, define your own enum and use it as
the C type parameter. Any Copy + Eq + Hash + Debug type
satisfies ColorKind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.